@@ -1,9 +1,9 @@
 <?php
 /*
- * @version $Id: private_public.php 17154 2012-01-24 11:27:36Z moyo $
+ * @version $Id: private_public.php 20130 2013-02-04 16:55:15Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
- Copyright (C) 2003-2012 by the INDEPNET Development Team.
+ Copyright (C) 2003-2013 by the INDEPNET Development Team.
 
  http://indepnet.net/   http://glpi-project.org
  -------------------------------------------------------------------------
@@ -36,7 +36,7 @@ if (strpos($_SERVER['PHP_SELF'],"private_public.php")) {
    define('GLPI_ROOT','..');
    include (GLPI_ROOT."/inc/includes.php");
    header("Content-Type: text/html; charset=UTF-8");
-   header_nocache();
+   Html::header_nocache();
 }
 
 if (!defined('GLPI_ROOT')) {
@@ -44,7 +44,7 @@ if (!defined('GLPI_ROOT')) {
 }
 
 if (isset($_POST['is_private'])) {
-   checkLoginUser();
+   Session::checkLoginUser();
 
    switch ($_POST['is_private']) {
       case true :
@@ -56,9 +56,15 @@ if (isset($_POST['is_private'])) {
          break;
 
       case false :
+         if (isset($_POST['entities_id'])
+             && in_array($_POST['entities_id'], $_SESSION['glpiactiveentities'])) {
+            $val = $_POST['entities_id'];
+         } else {
+            $val = $_SESSION['glpiactive_entity'];
+         }
          echo "<input type='hidden' name='is_private' value='0'>\n";
          echo $LANG['common'][76]."&nbsp;:&nbsp;";
-         Dropdown::show('Entity', array('value' => $_POST["entities_id"]));
+         Dropdown::show('Entity', array('value' => $val));
          echo "&nbsp;+&nbsp;".$LANG['entity'][9]."&nbsp;:&nbsp;";
          Dropdown::showYesNo('is_recursive', $_POST["is_recursive"]);
          echo " - ";
