@@ -1,9 +1,9 @@
 <?php
 /*
- * @version $Id: report.infocom.conso.php 17152 2012-01-24 11:22:16Z moyo $
+ * @version $Id: report.infocom.conso.php 20130 2013-02-04 16:55:15Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
- Copyright (C) 2003-2012 by the INDEPNET Development Team.
+ Copyright (C) 2003-2013 by the INDEPNET Development Team.
 
  http://indepnet.net/   http://glpi-project.org
  -------------------------------------------------------------------------
@@ -65,7 +65,8 @@ echo "<input type='submit' class='button' name='submit' value=\"".$LANG['buttons
 echo "<tr class='tab_bg_2'><td class='right'>".$LANG['search'][9]."&nbsp;:&nbsp;</td><td>";
 Html::showDateFormItem("date2", $_POST["date2"]);
 echo "</td></tr>";
-echo "</table></form>\n";
+echo "</table>\n";
+Html::closeForm();
 
 $valeurtot           = 0;
 $valeurnettetot      = 0;
