@@ -1,9 +1,9 @@
 <?php
 /*
- * @version $Id: software.php 17154 2012-01-24 11:27:36Z moyo $
+ * @version $Id: software.php 20130 2013-02-04 16:55:15Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
- Copyright (C) 2003-2012 by the INDEPNET Development Team.
+ Copyright (C) 2003-2013 by the INDEPNET Development Team.
 
  http://indepnet.net/   http://glpi-project.org
  -------------------------------------------------------------------------
@@ -36,12 +36,11 @@
 define('GLPI_ROOT', '..');
 include (GLPI_ROOT . "/inc/includes.php");
 
-checkRight("software","r");
+Session::checkRight("software", "r");
 
-commonHeader($LANG['Menu'][4],$_SERVER['PHP_SELF'],"inventory","software");
+Html::header($LANG['Menu'][4],$_SERVER['PHP_SELF'],"inventory","software");
 
 Search::show('Software');
 
-commonFooter();
-
-?>
+Html::footer();
+?>
\ No newline at end of file
