@@ -1,9 +1,9 @@
 <?php
 /*
- * @version $Id: transfer.action.php 17152 2012-01-24 11:22:16Z moyo $
+ * @version $Id: transfer.action.php 20130 2013-02-04 16:55:15Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
- Copyright (C) 2003-2012 by the INDEPNET Development Team.
+ Copyright (C) 2003-2013 by the INDEPNET Development Team.
 
  http://indepnet.net/   http://glpi-project.org
  -------------------------------------------------------------------------
@@ -49,15 +49,15 @@ if (isset($_POST['transfer'])) {
       }
       $transfer->moveItems($_SESSION['glpitransfer_list'], $_POST['to_entity'], $_POST);
       unset($_SESSION['glpitransfer_list']);
-      echo "<span class='b'>".$LANG['common'][23]."<br>";
-      echo "<a href='central.php'>".$LANG['buttons'][13]."</span></a>";
+      echo "<div class='b center'>".$LANG['common'][23]."<br>";
+      echo "<a href='central.php'>".$LANG['buttons'][13]."</a></div>";
       Html::footer();
       exit();
    }
 } else if (isset($_GET['clear'])) {
    unset($_SESSION['glpitransfer_list']);
-   echo "<span class='b'>".$LANG['common'][23]."<br>";
-   echo "<a href='central.php'>".$LANG['buttons'][13]."</span></a>";
+   echo "<div class='b center'>".$LANG['common'][23]."<br>";
+   echo "<a href='central.php'>".$LANG['buttons'][13]."</a></div>";
    Html::footer();
    exit();
 }
