@@ -1,9 +1,9 @@
 <?php
 /*
- * @version $Id: user.form.php 18797 2012-07-03 07:57:00Z moyo $
+ * @version $Id: user.form.php 20130 2013-02-04 16:55:15Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
- Copyright (C) 2003-2012 by the INDEPNET Development Team.
+ Copyright (C) 2003-2013 by the INDEPNET Development Team.
 
  http://indepnet.net/   http://glpi-project.org
  -------------------------------------------------------------------------
@@ -146,7 +146,7 @@ if (isset($_REQUEST['getvcard'])) {
    if (!isset($_REQUEST["ext_auth"])) {
       Session::checkRight("user", "r");
       Html::header($LANG['title'][13], '', "admin", "user");
-      $user->showForm($_REQUEST["id"]);
+      $user->showForm($_GET["id"]);
       Html::footer();
 
    } else {
