@@ -1,9 +1,9 @@
 <?php
 /*
- * @version $Id: authmail.class.php 17891 2012-03-19 06:21:48Z remi $
+ * @version $Id: authmail.class.php 20130 2013-02-04 16:55:15Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
- Copyright (C) 2003-2012 by the INDEPNET Development Team.
+ Copyright (C) 2003-2013 by the INDEPNET Development Team.
 
  http://indepnet.net/   http://glpi-project.org
  -------------------------------------------------------------------------
@@ -228,7 +228,8 @@ class AuthMail extends CommonDBTM {
 
          echo "<tr class='tab_bg_2'><td class='center' colspan='2'>";
          echo "<input type='submit' name='test' class='submit' value=\"".$LANG['buttons'][2]."\"></td>";
-         echo "</tr></table></div></form>";
+         echo "</tr></table></div>";
+         Html::closeForm();
       }
    }
 
