@@ -1,10 +1,10 @@
 <?php
 
 /*
- * @version $Id: budget.class.php 17154 2012-01-24 11:27:36Z moyo $
+ * @version $Id: budget.class.php 20130 2013-02-04 16:55:15Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
- Copyright (C) 2003-2012 by the INDEPNET Development Team.
+ Copyright (C) 2003-2013 by the INDEPNET Development Team.
 
  http://indepnet.net/   http://glpi-project.org
  -------------------------------------------------------------------------
@@ -40,20 +40,23 @@ class Budget extends CommonDropdown{
    // From CommonDBTM
    public $dohistory = true;
 
-   static function getTypeName() {
+   static function getTypeName($nb=0) {
       global $LANG;
 
+      if ($nb>1) {
+         return $LANG['financial'][110];
+      }
       return $LANG['financial'][87];
    }
 
 
    function canCreate() {
-      return haveRight('budget', 'w');
+      return Session::haveRight('budget', 'w');
    }
 
 
    function canView() {
-      return haveRight('budget', 'r');
+      return Session::haveRight('budget', 'r');
    }
 
 
@@ -61,28 +64,46 @@ class Budget extends CommonDropdown{
       global $LANG;
 
       $ong = array();
-      $ong[1] = $LANG['title'][26];
-
-      if ($this->fields['id'] > 0) {
-         if (haveRight("document","r")) {
-            $ong[5] = $LANG['Menu'][27];
-         }
-         if (!isset($options['withtemplate']) || empty($options['withtemplate'])) {
-            $ong[2] = $LANG['common'][96];
-            if (haveRight("link","r")) {
-               $ong[7] = $LANG['title'][34];
-            }
-            if (haveRight("notes","r")) {
-               $ong[10] = $LANG['title'][37];
-            }
-            $ong[12] = $LANG['title'][38];
-         }
-      }
+      $this->addStandardTab(__CLASS__,$ong, $options);
+      $this->addStandardTab('Document',$ong, $options);
+      $this->addStandardTab('Link',$ong, $options);
+      $this->addStandardTab('Note',$ong, $options);
+      $this->addStandardTab('Log',$ong, $options);
 
       return $ong;
    }
 
 
+   function getTabNameForItem(CommonGLPI $item, $withtemplate=0) {
+      global $LANG;
+
+      if (!$withtemplate) {
+         switch ($item->getType()) {
+            case __CLASS__ :
+               return array (1 => $LANG['title'][26],
+                             2 => $LANG['common'][96]);
+         }
+      }
+      return '';
+   }
+
+
+   static function displayTabContentForItem(CommonGLPI $item, $tabnum=1, $withtemplate=0) {
+
+      if ($item->getType() == __CLASS__) {
+         switch ($tabnum) {
+            case 1 :
+               $item->showValuesByEntity();
+               break;
+            case 2 :
+               $item->showItems();
+               break;
+         }
+      }
+      return true;
+   }
+
+
    /**
     * Print the contact form
     *
@@ -93,11 +114,9 @@ class Budget extends CommonDropdown{
     *
     *@return Nothing (display)
     **/
-   function showForm ($ID, $options=array()) {
+   function showForm($ID, $options=array()) {
       global $LANG;
 
-      if (!haveRight("budget","r")) return false;
-
       $use_cache = true;
 
       $rowspan = 4;
@@ -115,7 +134,7 @@ class Budget extends CommonDropdown{
       echo "<tr class='tab_bg_1'>";
       echo "<td>".$LANG['common'][16]."&nbsp;: </td>";
       echo "<td>";
-      autocompletionTextField($this, "name");
+      Html::autocompletionTextField($this, "name");
       echo "</td>";
 
       echo "<td rowspan='$rowspan' class='middle right'>".$LANG['common'][25]."&nbsp;: </td>";
@@ -125,25 +144,26 @@ class Budget extends CommonDropdown{
       echo "<tr class='tab_bg_1'>";
       echo "<td>".$LANG['financial'][21]."&nbsp;:</td>";
       echo "<td><input type='text' name='value' size='14'
-             value='".formatNumber($this->fields["value"], true)."'></td></tr>";
+             value='".Html::formatNumber($this->fields["value"], true)."'></td></tr>";
 
       echo "<tr class='tab_bg_1'>";
       echo "<td>".$LANG['search'][8]."&nbsp;: </td>";
       echo "<td>";
-      showDateFormItem("begin_date", $this->fields["begin_date"]);
+      Html::showDateFormItem("begin_date", $this->fields["begin_date"]);
       echo "</td></tr>";
 
       echo "<tr class='tab_bg_1'>";
       echo "<td>".$LANG['search'][9]."&nbsp;: </td>";
       echo "<td>";
-      showDateFormItem("end_date",$this->fields["end_date"]);
+      Html::showDateFormItem("end_date",$this->fields["end_date"]);
       echo "</td></tr>";
 
       if ($ID>0) {
          echo "<tr class='tab_bg_1'>";
          echo "<td>".$LANG['common'][26]."&nbsp;: </td>";
          echo "<td>";
-         echo ($this->fields["date_mod"]?convDateTime($this->fields["date_mod"]):$LANG['setup'][307]);
+         echo ($this->fields["date_mod"]?Html::convDateTime($this->fields["date_mod"])
+                                        :$LANG['setup'][307]);
          echo "</td></tr>";
       }
 
@@ -240,7 +260,7 @@ class Budget extends CommonDropdown{
       $tab[90]['field']         = 'notepad';
       $tab[90]['name']          = $LANG['title'][37];
       $tab[90]['massiveaction'] = false;
-      
+
       return $tab;
    }
 
@@ -270,7 +290,7 @@ class Budget extends CommonDropdown{
 
       echo "<div class='spaced'><table class='tab_cadre_fixehov'>";
       echo "<tr><th colspan='2'>";
-      printPagerForm();
+      Html::printPagerForm();
       echo "</th><th colspan='4'>";
       if ($DB->numrows($result)==0) {
          echo $LANG['document'][13];
@@ -291,10 +311,10 @@ class Budget extends CommonDropdown{
       for ($i = 0; $i < $number ; $i++) {
          $itemtype = $DB->result($result, $i, "itemtype");
 
-         if (!class_exists($itemtype)) {
+         if (!($item = getItemForItemtype($itemtype))) {
             continue;
          }
-         $item = new $itemtype();
+
          if ($item->canView()) {
             switch ($itemtype) {
                default :
@@ -379,7 +399,8 @@ class Budget extends CommonDropdown{
                      echo "<td class='center'>".
                             (isset($data["otherserial"])? "".$data["otherserial"]."" :"-")."</td>";
                      echo "<td class='center'>".
-                            (isset($data["value"])? "".formatNumber($data["value"],true)."" :"-");
+                            (isset($data["value"]) ? "".Html::formatNumber($data["value"], true).""
+                                                   :"-");
 
                      echo "</td></tr>";
                   }
@@ -428,10 +449,10 @@ class Budget extends CommonDropdown{
 
       if ($DB->numrows($result)) {
          while ($types = $DB->fetch_array($result)) {
-            if (!class_exists($types['itemtype'])) {
+            if (!($item = getItemForItemtype($types['itemtype']))) {
                continue;
             }
-            $item = new $types['itemtype']();
+
             $found_types[$types['itemtype']] = $item->getTypeName();
             $table = getTableForItemType($types['itemtype']);
             $query_infos = "SELECT SUM(`glpi_infocoms`.`value`) AS `sumvalue`,
@@ -492,12 +513,12 @@ class Budget extends CommonDropdown{
                   if (isset($entitiestype_values[$entity][$type])) {
                      $typevalue = $entitiestype_values[$entity][$type];
                   }
-                  echo formatNumber($typevalue);
+                  echo Html::formatNumber($typevalue);
                   echo "</td>";
                }
             }
 
-            echo "<td class='right b'>".formatNumber($value)."</td>";
+            echo "<td class='right b'>".Html::formatNumber($value)."</td>";
             echo "</tr>";
             $total += $value;
          }
@@ -505,11 +526,12 @@ class Budget extends CommonDropdown{
          echo "<tr class='tab_bg_1'><th colspan='$colspan'><br></th></tr>";
          echo "<tr class='tab_bg_1'>";
          echo "<td class='right' colspan='".($colspan-1)."'>".$LANG['financial'][108]."</td>";
-         echo "<td class='right b'>".formatNumber($total)."</td></tr>";
+         echo "<td class='right b'>".Html::formatNumber($total)."</td></tr>";
          if ($_SESSION['glpiactive_entity'] == $budget->fields['entities_id']) {
             echo "<tr class='tab_bg_1'>";
             echo "<td class='right' colspan='".($colspan-1)."'>".$LANG['financial'][109]."</td>";
-            echo "<td class='right b'>".formatNumber($budget->fields['value'] - $total)."</td></tr>";
+            echo "<td class='right b'>".Html::formatNumber($budget->fields['value'] - $total).
+                 "</td></tr>";
          }
          echo "</table></div>";
 
