@@ -1,9 +1,9 @@
 <?php
 /*
- * @version $Id: commonitiltask.class.php 18849 2012-07-05 11:12:13Z moyo $
+ * @version $Id: commonitiltask.class.php 21018 2013-05-28 06:56:33Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
- Copyright (C) 2003-2012 by the INDEPNET Development Team.
+ Copyright (C) 2003-2013 by the INDEPNET Development Team.
 
  http://indepnet.net/   http://glpi-project.org
  -------------------------------------------------------------------------
@@ -93,7 +93,7 @@ abstract class CommonITILTask  extends CommonDBTM {
    function getTabNameForItem(CommonGLPI $item, $withtemplate=0) {
       global $LANG;
 
-      if ($item->getType() == $this->getItilObjectItemType() && $item->canView()) {
+      if ($item->getType() == $this->getItilObjectItemType() && $this->canView()) {
          if ($_SESSION['glpishow_count_on_tabs']) {
             $restrict = "`".$item->getForeignKeyField()."` = '".$item->getID()."'";
 
@@ -456,34 +456,36 @@ abstract class CommonITILTask  extends CommonDBTM {
 
       // Get items to print
       $ASSIGN = "";
-
       if ($who_group==="mine") {
          if (count($_SESSION["glpigroups"])) {
             $groups = implode("','",$_SESSION['glpigroups']);
-            $ASSIGN = "`users_id_tech` IN (SELECT DISTINCT `users_id`
-                                      FROM `glpi_groups_users`
-                                      WHERE `groups_id` IN ('$groups'))
+            $ASSIGN = "`".$item->getTable()."`.`users_id_tech` IN (SELECT DISTINCT `users_id`
+                                                                   FROM `glpi_groups_users`
+                                                                   INNER JOIN `glpi_groups`
+                                                                     ON (`glpi_groups_users`.`groups_id` = `glpi_groups`.`id`)
+                                                                   WHERE `glpi_groups_users`.`groups_id` IN ('$groups')
+                                                                           AND `glpi_groups`.`is_assign`)
                                             AND ";
          } else { // Only personal ones
-            $ASSIGN = "`users_id_tech` = '$who'
+            $ASSIGN = "`".$item->getTable()."`.`users_id_tech` = '$who'
                        AND ";
          }
 
       } else {
          if ($who>0) {
-            $ASSIGN = "`users_id_tech` = '$who'
+            $ASSIGN = "`".$item->getTable()."`.`users_id_tech` = '$who'
                        AND ";
          }
 
          if ($who_group>0) {
-            $ASSIGN = "`users_id_tech` IN (SELECT `users_id`
+            $ASSIGN = "`".$item->getTable()."`.`users_id_tech` IN (SELECT `users_id`
                                       FROM `glpi_groups_users`
                                       WHERE `groups_id` = '$who_group')
                                             AND ";
          }
       }
       if (empty($ASSIGN)) {
-         $ASSIGN = "`users_id_tech` IN (SELECT DISTINCT `glpi_profiles_users`.`users_id`
+         $ASSIGN = "`".$item->getTable()."`.`users_id_tech` IN (SELECT DISTINCT `glpi_profiles_users`.`users_id`
                                    FROM `glpi_profiles`
                                    LEFT JOIN `glpi_profiles_users`
                                      ON (`glpi_profiles`.`id` = `glpi_profiles_users`.`profiles_id`)
@@ -494,12 +496,20 @@ abstract class CommonITILTask  extends CommonDBTM {
          $ASSIGN .= ") AND ";
       }
 
-      $query = "SELECT *
+      $addrestrict = '';
+      if ($parentitem->maybeDeleted()) {
+         $addrestrict .= 'AND NOT `'.$parentitem->getTable().'`.`is_deleted`';
+      }
+      
+      $query = "SELECT `".$item->getTable()."`.*
                 FROM `".$item->getTable()."`
+                INNER JOIN `".$parentitem->getTable()."`
+                  ON (`".$parentitem->getTable()."`.`id` = `".$item->getTable()."`.`".$parentitem->getForeignKeyField()."`)
                 WHERE $ASSIGN
-                      '$begin' < `end`
-                      AND '$end' > `begin`
-                ORDER BY `begin`";
+                      '$begin' < `".$item->getTable()."`.`end`
+                      AND '$end' > `".$item->getTable()."`.`begin`
+                      $addrestrict
+                ORDER BY `".$item->getTable()."`.`begin`";
 
       $result = $DB->query($query);
 
