@@ -1,9 +1,9 @@
 <?php
 /*
- * @version $Id: item_problem.class.php 18771 2012-06-29 08:49:19Z moyo $
+ * @version $Id: item_problem.class.php 20130 2013-02-04 16:55:15Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
- Copyright (C) 2003-2012 by the INDEPNET Development Team.
+ Copyright (C) 2003-2013 by the INDEPNET Development Team.
 
  http://indepnet.net/   http://glpi-project.org
  -------------------------------------------------------------------------
@@ -244,15 +244,18 @@ class Item_Problem extends CommonDBRelation{
                return $LANG['common'][96];
 
             default :
-               // Direct one
                if (Session::haveRight("show_all_problem","1")) {
-                  $nb = countElementsInTable('glpi_items_problems',
-                                             " `itemtype` = '".$item->getType()."'
-                                                AND `items_id` = '".$item->getID()."'");
-                  // Linked items
-                  if ($subquery = $item->getSelectLinkedItem()) {
-                     $nb += countElementsInTable('glpi_items_problems',
-                                                   "(`itemtype`,`items_id`) IN (" . $subquery . ")");
+                  $nb = 0;
+                  if ($_SESSION['glpishow_count_on_tabs']) {
+                     // Direct one
+                     $nb = countElementsInTable('glpi_items_problems',
+                                                " `itemtype` = '".$item->getType()."'
+                                                   AND `items_id` = '".$item->getID()."'");
+                     // Linked items
+                     if ($subquery = $item->getSelectLinkedItem()) {
+                        $nb += countElementsInTable('glpi_items_problems',
+                                                      "(`itemtype`,`items_id`) IN (" . $subquery . ")");
+                     }
                   }
                   return self::createTabEntry($LANG['Menu'][7], $nb);
                }
