@@ -1,9 +1,9 @@
 <?php
 /*
- * @version $Id: notificationtargetdbconnection.class.php 17154 2012-01-24 11:27:36Z moyo $
+ * @version $Id: notificationtargetdbconnection.class.php 20130 2013-02-04 16:55:15Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
- Copyright (C) 2003-2012 by the INDEPNET Development Team.
+ Copyright (C) 2003-2013 by the INDEPNET Development Team.
 
  http://indepnet.net/   http://glpi-project.org
  -------------------------------------------------------------------------
@@ -58,7 +58,7 @@ class NotificationTargetDBConnection extends NotificationTarget {
       if ($options['diff'] > 1000000000) {
          $tmp = $LANG['install'][35];
       } else {
-         $tmp = timestampToString($options['diff'], true);
+         $tmp = Html::timestampToString($options['diff'], true);
       }
       $this->datas['##dbconnection.delay##'] = $tmp." (".$options['name'].")";
 
@@ -68,6 +68,7 @@ class NotificationTargetDBConnection extends NotificationTarget {
             $this->datas[$tag] = $values['label'];
          }
       }
+
    }
 
 
