@@ -1,9 +1,9 @@
 <?php
 /*
- * @version $Id: notificationtargetticket.class.php 18719 2012-06-26 06:57:34Z moyo $
+ * @version $Id: notificationtargetticket.class.php 20811 2013-04-26 07:15:37Z yllen $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
- Copyright (C) 2003-2012 by the INDEPNET Development Team.
+ Copyright (C) 2003-2013 by the INDEPNET Development Team.
 
  http://indepnet.net/   http://glpi-project.org
  -------------------------------------------------------------------------
@@ -91,6 +91,9 @@ class NotificationTargetTicket extends NotificationTargetCommonITILObject {
       return parent::getSubjectPrefix();
    }
 
+   function getMessageID() {
+      return "GLPI-".$this->obj->getField('id').".".time().".".rand(). "@".php_uname('n');
+   }
 
    function addAdditionnalInfosForTarget() {
       global $DB;
@@ -312,11 +315,11 @@ class NotificationTargetTicket extends NotificationTargetCommonITILObject {
                                                       $hardware->getField('groups_id'));
          }
 
-         $modeltable = getSingular($this->getTable())."models";
+         $modeltable = getSingular($hardware->getTable())."models";
          $modelfield = getForeignKeyFieldForTable($modeltable);
 
          if ($hardware->isField($modelfield)) {
-            $datas['##ticket.item.model##'] = $hardware->getField($modelfield);
+            $datas['##ticket.item.model##'] = Dropdown::getDropdownName($modeltable, $hardware->getField($modelfield));
          }
 
       }
@@ -387,17 +390,15 @@ class NotificationTargetTicket extends NotificationTargetCommonITILObject {
             $tmp['##task.date##']        = Html::convDateTime($task['date']);
             $tmp['##task.description##'] = $task['content'];
             $tmp['##task.time##']        = Ticket::getActionTime($task['actiontime']);
-
+            $tmp['##task.status##'] = Planning::getState($task['state']);
 
             $tmp['##task.user##']   = "";
             $tmp['##task.begin##']  = "";
             $tmp['##task.end##']    = "";
-            $tmp['##task.status##'] = "";
             if (!is_null($task['begin'])) {
                $tmp['##task.user##']   = Html::clean(getUserName($task['users_id_tech']));
                $tmp['##task.begin##']  = Html::convDateTime($task['begin']);
                $tmp['##task.end##']    = Html::convDateTime($task['end']);
-               $tmp['##task.status##'] = Planning::getState($task['state']);
             }
 
             $datas['tasks'][] = $tmp;
@@ -604,8 +605,8 @@ class NotificationTargetTicket extends NotificationTargetCommonITILObject {
       // Events for ticket satisfaction
       $tags = array('satisfaction.datebegin'           => $LANG['satisfaction'][6],
                     'satisfaction.dateanswered'        => $LANG['satisfaction'][4],
-                    'satisfaction.satisfactionlevel'   => $LANG['satisfaction'][7],
-                    'satisfaction.satisfactioncomment' => $LANG['satisfaction'][8]);
+                    'satisfaction.satisfaction'        => $LANG['satisfaction'][7],
+                    'satisfaction.description'         => $LANG['satisfaction'][8]);
 
       foreach ($tags as $tag => $label) {
          $this->addTagToList(array('tag'    => $tag,
