@@ -1,9 +1,9 @@
 <?php
 /*
- * @version $Id: relation.constant.php 17303 2012-01-31 12:32:34Z moyo $
+ * @version $Id: relation.constant.php 21089 2013-06-07 08:43:38Z tsmr $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
- Copyright (C) 2003-2012 by the INDEPNET Development Team.
+ Copyright (C) 2003-2013 by the INDEPNET Development Team.
 
  http://indepnet.net/   http://glpi-project.org
  -------------------------------------------------------------------------
@@ -249,7 +249,8 @@ $RELATION = array("glpi_authldaps"
                                  'glpi_printers'          => array('groups_id_tech', 'groups_id'),
                                  'glpi_softwares'         => array('groups_id_tech', 'groups_id'),
                                  'glpi_cartridgeitems'    => 'groups_id_tech',
-                                 'glpi_consumableitems'   => 'groups_id_tech'),
+                                 'glpi_consumableitems'   => 'groups_id_tech',
+                                 'glpi_itilcategories'    => 'groups_id'),
 
                   "glpi_holidays"
                         => array('glpi_calendars_holidays' => 'holidays_id',),
@@ -484,7 +485,7 @@ $RELATION = array("glpi_authldaps"
                         => array('glpi_suppliers' => 'suppliertypes_id'),
 
                   "glpi_taskcategories"
-                        => array('glpi_changetasks'    => 'taskcategories_id',
+                        => array(/*'glpi_changetasks'    => 'taskcategories_id',*/
                                  'glpi_problemtasks'   => 'taskcategories_id',
                                  'glpi_taskcategories' => 'taskcategories_id',
                                  'glpi_tickettasks'    => 'taskcategories_id'),
@@ -499,11 +500,11 @@ $RELATION = array("glpi_authldaps"
                         => array('glpi_itilcategories'      => array('tickettemplates_id_incident',
                                                                      'tickettemplates_id_demand'),
                                  'glpi_ticketrecurrents'    => 'tickettemplates_id',
-                                 'glpi_tickettemplatehiddenfields'
+                                 '_glpi_tickettemplatehiddenfields'
                                                             => 'tickettemplates_id',
-                                 'glpi_tickettemplatepredefinedfields'
+                                 '_glpi_tickettemplatepredefinedfields'
                                                             => 'tickettemplates_id',
-                                 'glpi_tickettemplatemandatoryfields'
+                                 '_glpi_tickettemplatemandatoryfields'
                                                             => 'tickettemplates_id'),
 
                   "glpi_tickets"
@@ -565,7 +566,8 @@ $RELATION = array("glpi_authldaps"
                                                                      'users_id_lastupdater'),
                                  'glpi_tickets_users'       => 'users_id',
                                  'glpi_tickettasks'         => array('users_id', 'users_id_tech'),
-                                 'glpi_useremails'          => 'users_id'),
+                                 'glpi_useremails'          => 'users_id',
+                                 'glpi_itilcategories'      => 'users_id'),
 
                   "glpi_usertitles"
                         => array('glpi_users' => 'usertitles_id'),
