@@ -1,9 +1,9 @@
 <?php
 /*
- * @version $Id: reminder.class.php 18771 2012-06-29 08:49:19Z moyo $
+ * @version $Id: reminder.class.php 20130 2013-02-04 16:55:15Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
- Copyright (C) 2003-2012 by the INDEPNET Development Team.
+ Copyright (C) 2003-2013 by the INDEPNET Development Team.
 
  http://indepnet.net/   http://glpi-project.org
  -------------------------------------------------------------------------
@@ -335,6 +335,7 @@ class Reminder extends CommonDBTM {
       $tab[1]['datatype']      = 'itemlink';
       $tab[1]['itemlink_link'] = $this->getType();
       $tab[1]['massiveaction'] = false;
+      $tab[1]['forcegroupby']  = true;
 
       $tab[2]['table']         = 'glpi_users';
       $tab[2]['field']         = 'name';
@@ -398,11 +399,13 @@ class Reminder extends CommonDBTM {
       if (Session::haveRight("reminder_public","r")) {
          switch ($item->getType()) {
             case 'Reminder' :
-               if ($_SESSION['glpishow_count_on_tabs']) {
-                  return array(1 => self::createTabEntry($LANG['reminder'][2],
-                                                         $item->countVisibilities()));
+               if ($item->canUpdate()) {
+                  if ($_SESSION['glpishow_count_on_tabs']) {
+                     return array(1 => self::createTabEntry($LANG['reminder'][2],
+                                                            $item->countVisibilities()));
+                  }
+                  return array(1 => $LANG['reminder'][2]);
                }
-               return array(1 => $LANG['reminder'][2]);
          }
       }
       return '';
@@ -712,10 +715,8 @@ class Reminder extends CommonDBTM {
 
       $interv  = array();
 
-      if (!isset($options['begin'])
-          || !isset($options['begin'])
-          || !isset($options['begin'])
-          || !isset($options['end'])) {
+      if (!isset($options['begin']) || ($options['begin'] == 'NULL')
+          || !isset($options['end']) || ($options['end'] == 'NULL')) {
          return $interv;
       }
 
@@ -723,22 +724,34 @@ class Reminder extends CommonDBTM {
       $who_group = $options['who_group'];
       $begin     = $options['begin'];
       $end       = $options['end'];
-
       $readpub = $readpriv="";
 
-      $joinstoadd = '';
+      $joinstoadd = self::addVisibilityJoins(true);
 
       // See public reminder ?
-      if (Session::haveRight("reminder_public","r")) {
+      if ($who===Session::getLoginUserID() && Session::haveRight("reminder_public","r")) {
          $readpub    = self::addVisibilityRestrict();
-         $joinstoadd = self::addVisibilityJoins();
       }
 
       // See my private reminder ?
-      if ($who_group=="mine" || $who===Session::getLoginUserID()) {
+      if ($who_group==="mine" || $who===Session::getLoginUserID()) {
          $readpriv = "(`glpi_reminders`.`users_id` = '".Session::getLoginUserID()."')";
+      } else {
+         if ($who > 0) {
+            $readpriv = "`glpi_reminders`.`users_id` = '$who'";
+         }
+         if ($who_group > 0) {
+            if (!empty($readpriv)) {
+               $readpriv .= " OR ";
+            }
+            $readpriv .= " `glpi_groups_reminders`.`groups_id` = '$who_group'";
+         }
+         if (!empty($readpriv)) {
+            $readpriv = '('.$readpriv.')';
+         }
       }
 
+      $ASSIGN = '';
       if (!empty($readpub) && !empty($readpriv)) {
          $ASSIGN = "($readpub OR $readpriv)";
       } else if ($readpub) {
@@ -748,7 +761,7 @@ class Reminder extends CommonDBTM {
       }
 
       if ($ASSIGN) {
-         $query2 = "SELECT `glpi_reminders`.*
+         $query2 = "SELECT DISTINCT `glpi_reminders`.*
                     FROM `glpi_reminders`
                     $joinstoadd
                     WHERE `glpi_reminders`.`is_planned` = '1'
@@ -756,6 +769,7 @@ class Reminder extends CommonDBTM {
                           AND `begin` < '$end'
                           AND `end` > '$begin'
                     ORDER BY `begin`";
+
          $result2 = $DB->query($query2);
 
          if ($DB->numrows($result2)>0) {
@@ -1152,7 +1166,7 @@ class Reminder extends CommonDBTM {
       echo "<div class='firstbloc'>";
       echo "<table class='tab_cadre_fixe'>";
       echo "<tr class='tab_bg_1'><th colspan='4'>".$LANG['common'][116]."</tr>";
-      echo "<tr><td class='tab_bg_2' width='100px'>";
+      echo "<tr class='tab_bg_2'><td width='100px'>";
 
       $types = array( 'Group', 'Profile', 'User', 'Entity');
 
@@ -1183,7 +1197,7 @@ class Reminder extends CommonDBTM {
       if (count($this->users)) {
          foreach ($this->users as $key => $val) {
             foreach ($val as $data) {
-               echo "<tr>";
+               echo "<tr class='tab_bg_2'>";
                if ($canedit) {
                   echo "<td>";
                   $sel = "";
@@ -1204,7 +1218,7 @@ class Reminder extends CommonDBTM {
       if (count($this->groups)) {
          foreach ($this->groups as $key => $val) {
             foreach ($val as $data) {
-               echo "<tr>";
+               echo "<tr class='tab_bg_2'>";
                if ($canedit) {
                   echo "<td>";
                   $sel = "";
@@ -1227,7 +1241,7 @@ class Reminder extends CommonDBTM {
                   }
                }
                echo "</td>";
-               echo "<tr>";
+               echo "</tr>";
             }
          }
       }
@@ -1236,7 +1250,7 @@ class Reminder extends CommonDBTM {
       if (count($this->entities)) {
          foreach ($this->entities as $key => $val) {
             foreach ($val as $data) {
-               echo "<tr>";
+               echo "<tr class='tab_bg_2'>";
                if ($canedit) {
                   echo "<td>";
                   $sel = "";
@@ -1255,7 +1269,7 @@ class Reminder extends CommonDBTM {
                   echo " <span class='b'>&nbsp;(R)</span>";
                }
                echo "</td>";
-               echo "<tr>";
+               echo "</tr>";
             }
          }
       }
@@ -1264,7 +1278,7 @@ class Reminder extends CommonDBTM {
       if (count($this->profiles)) {
          foreach ($this->profiles as $key => $val) {
             foreach ($val as $data) {
-               echo "<tr>";
+               echo "<tr class='tab_bg_2'>";
                if ($canedit) {
                   echo "<td>";
                   $sel = "";
@@ -1287,13 +1301,13 @@ class Reminder extends CommonDBTM {
                   }
                }
                echo "</td>";
-               echo "<tr>";
+               echo "</tr>";
             }
          }
       }
 
       if ($canedit) {
-         echo "<tr><td colspan='3'>";
+         echo "<tr class='tab_bg_2'><td colspan='3'>";
          echo "</td></tr>";
       }
       echo "</table>";
