@@ -2,10 +2,10 @@
 
 
 /*
- * @version $Id: ruledictionnaryprintercollection.class.php 17154 2012-01-24 11:27:36Z moyo $
+ * @version $Id: ruledictionnaryprintercollection.class.php 20130 2013-02-04 16:55:15Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
- Copyright (C) 2003-2012 by the INDEPNET Development Team.
+ Copyright (C) 2003-2013 by the INDEPNET Development Team.
 
  http://indepnet.net/   http://glpi-project.org
  -------------------------------------------------------------------------
@@ -52,7 +52,7 @@ class RuleDictionnaryPrinterCollection extends RuleCachedCollection {
    function __construct() {
 
       //Init cache system values
-      $this->initCache("glpi_rulecacheprinters", 
+      $this->initCache("glpi_rulecacheprinters",
                        array("name"               => "old_value",
                              "manufacturer"       => "manufacturer"),
                        array("name"               => "new_value",
@@ -107,7 +107,7 @@ class RuleDictionnaryPrinterCollection extends RuleCachedCollection {
       if ($offset) {
          $sql .= " LIMIT " . intval($offset) . ",999999999";
       }
-      
+
       $res  = $DB->query($sql);
       $nb   = $DB->numrows($res) + $offset;
       $step = ($nb > 1000 ? 50 : ($nb > 20 ? floor($DB->numrows($res) / 20) : 1));
@@ -118,21 +118,21 @@ class RuleDictionnaryPrinterCollection extends RuleCachedCollection {
                echo date("H:i:s") . " replayRulesOnExistingDB : $i/$nb (" .
                     round(memory_get_usage() / (1024 * 1024), 2) . " Mo)\n";
             } else {
-               changeProgressBarPosition($i, $nb, "$i / $nb");
+               Html::changeProgressBarPosition($i, $nb, "$i / $nb");
             }
          }
 
          //Replay printer dictionnary rules
-         $input    = addslashes_deep($input);
+         $input    = Toolbox::addslashes_deep($input);
          $res_rule = $this->processAllRules($input, array(), array());
-         $res_rule = addslashes_deep($res_rule);
+         $res_rule = Toolbox::addslashes_deep($res_rule);
 
          foreach (array('manufacturer', 'is_global', 'name') as $attr) {
             if (isset($res_rule[$attr]) && $res_rule[$attr] == '') {
                unset($res_rule[$attr]);
             }
          }
-         
+
          //If the software's name or version has changed
          if (self::somethingHasChanged($res_rule, $input)) {
 
@@ -145,12 +145,12 @@ class RuleDictionnaryPrinterCollection extends RuleCachedCollection {
             $res_printer = $DB->query($sql);
 
             if ($DB->numrows($res_printer) > 0) {
-               //Store all the software's IDs in an array
+               //Store all the printer's IDs in an array
                while ($result = $DB->fetch_array($res_printer)) {
                   $IDs[] = $result["id"];
                }
-               //Replay dictionnary on all the softwares
-               $this->replayDirectionnaryOnPrintersByID($IDs, $res_rule);
+               //Replay dictionnary on all the printers
+               $this->replayDictionnaryOnPrintersByID($IDs, $res_rule);
             }
          }
          $i++;
@@ -166,7 +166,7 @@ class RuleDictionnaryPrinterCollection extends RuleCachedCollection {
       if (isCommandLine()) {
          echo "replayRulesOnExistingDB : $i/$nb               \n";
       } else {
-         changeProgressBarPosition($i, $nb, "$i / $nb");
+         Html::changeProgressBarPosition($i, $nb, "$i / $nb");
       }
 
       if (isCommandLine()) {
@@ -178,16 +178,16 @@ class RuleDictionnaryPrinterCollection extends RuleCachedCollection {
 
 
    static function somethingHasChanged($res_rule, $input) {
-      if ((isset ($res_rule["name"]) && $res_rule["name"] != $input["name"])
-          || (isset($res_rule["manufacturer"]))
-            && $res_rule["manufacturer"] != ''
-               || isset($res_rule['is_global'])
-                  && $res_rule['is_global'] != '') {
-            return true;
+
+      if ((isset($res_rule["name"]) && $res_rule["name"] != $input["name"])
+          || (isset($res_rule["manufacturer"]) && $res_rule["manufacturer"] != '')
+          || (isset($res_rule['is_global']) && $res_rule['is_global'] != '')) {
+         return true;
       }
       return false;
    }
 
+
    /**
     * Replay dictionnary on several printers
     *
@@ -196,23 +196,23 @@ class RuleDictionnaryPrinterCollection extends RuleCachedCollection {
     *
     * @return Query result handler
    **/
-   function replayDirectionnaryOnPrintersByID($IDs, $res_rule = array()) {
+   function replayDictionnaryOnPrintersByID($IDs, $res_rule=array()) {
       global $DB;
 
       $new_printers  = array();
-      $delete_ids = array();
+      $delete_ids    = array();
 
       foreach ($IDs as $ID) {
-         $sql = "SELECT `gp`.`id`,
-                        `gp`.`name` AS name,
-                        `gp`.`entities_id` AS entities_id,
-                        `gp`.`is_global` AS is_global,
-                        `gm`.`name` AS manufacturer
-                 FROM `glpi_printers` AS gp
-                 LEFT JOIN `glpi_manufacturers` AS gm
-                    ON (`gp`.`manufacturers_id` = `gm`.`id`)
-                 WHERE `gp`.`is_template` = '0'
-                    AND `gp`.`id` = '$ID'";
+         $sql = "SELECT `glpi_printers`.`id`,
+                        `glpi_printers`.`name` AS name,
+                        `glpi_printers`.`entities_id` AS entities_id,
+                        `glpi_printers`.`is_global` AS is_global,
+                        `glpi_manufacturers`.`name` AS manufacturer
+                 FROM `glpi_printers`
+                 LEFT JOIN `glpi_manufacturers`
+                    ON (`glpi_printers`.`manufacturers_id` = `glpi_manufacturers`.`id`)
+                 WHERE `glpi_printers`.`is_template` = '0'
+                       AND `glpi_printers`.`id` = '$ID'";
 
          $res_printer = $DB->query($sql);
          if ($DB->numrows($res_printer)) {
@@ -224,26 +224,26 @@ class RuleDictionnaryPrinterCollection extends RuleCachedCollection {
       //Delete printer if needed
       $this->putOldPrintersInTrash($delete_ids);
    }
-   
+
+
    function putOldPrintersInTrash($IDS = array()) {
-      $printer = new Printer;
+
+      $printer = new Printer();
       foreach ($IDS as $id) {
          $printer->delete(array('id' => $id));
       }
    }
-   
+
+
    /**
     * Replay dictionnary on one printer
     *
-    * @param $new_softs array containing new printers already computed
+    * @param $new_printers array containing new printers already computed
     * @param $res_rule array of rule results
-    * @param $ID ID of the software
-    * @param $entity working entity ID
-    * @param $name printer name
-    * @param $manufacturer manufacturer ID
+    * @param $params array
     * @param $printers_ids array containing replay printer need to be trashed
    **/
-   function replayDictionnaryOnOnePrinter(& $new_printers, $res_rule, $params = array(), 
+   function replayDictionnaryOnOnePrinter(& $new_printers, $res_rule, $params = array(),
                                           & $printers_ids) {
       global $DB;
 
@@ -255,31 +255,31 @@ class RuleDictionnaryPrinterCollection extends RuleCachedCollection {
       foreach ($params as $key => $value) {
          $p[$key] = $value;
       }
-      
+
       $input["name"]         = $p['name'];
       $input["manufacturer"] = $p['manufacturer'];
-      $input                 = addslashes_deep($input);
+      $input                 = Toolbox::addslashes_deep($input);
 
-      if (empty ($res_rule)) {
+      if (empty($res_rule)) {
          $res_rule = $this->processAllRules($input, array(), array());
-         $res_rule = addslashes_deep($res_rule);
+         $res_rule = Toolbox::addslashes_deep($res_rule);
       }
 
       $printer = new Printer();
 
       //Printer's name has changed
-      if (isset ($res_rule["name"])
-            && $res_rule["name"] != $p['name']) {
+      if (isset($res_rule["name"])
+          && $res_rule["name"] != $p['name']) {
 
          $manufacturer = "";
-         if (isset ($res_rule["manufacturer"])) {
+
+         if (isset($res_rule["manufacturer"])) {
             $manufacturer = Dropdown::getDropdownName("glpi_manufacturers",
                                                       $res_rule["manufacturer"]);
-                                                      
          }
 
          //New printer not already present in this entity
-         if (!isset ($new_printers[$p['entity']][$res_rule["name"]])) {
+         if (!isset($new_printers[$p['entity']][$res_rule["name"]])) {
             // create new printer or restore it from trash
             $new_printer_id = $printer->addOrRestoreFromTrash($res_rule["name"], $manufacturer,
                                                               $p['entity']);
@@ -287,7 +287,7 @@ class RuleDictionnaryPrinterCollection extends RuleCachedCollection {
          } else {
             $new_printer_id = $new_printers[$p['entity']][$res_rule["name"]];
          }
-         
+
          // Move direct connections
          $this->moveDirectConnections($p['id'], $new_printer_id);
 
@@ -311,27 +311,29 @@ class RuleDictionnaryPrinterCollection extends RuleCachedCollection {
 
    }
 
+
    /**
     * Move direct connections from old printer to the new one
-    * @params $ID the old printer's id
-    * @params $new_printers_id the new printer's id
-    * 
+    * @param $ID the old printer's id
+    * @param $new_printers_id the new printer's id
+    *
     * @return nothing
-    */
+   **/
    function moveDirectConnections($ID, $new_printers_id) {
       global $DB;
+
       $computeritem = new Computer_Item();
       //For each direct connection of this printer
-      foreach (getAllDatasFromTable("glpi_computers_items", 
+      foreach (getAllDatasFromTable("glpi_computers_items",
                                     "`itemtype` = 'Printer' AND `items_id` = '$ID'") as $connection) {
-         
+
          //Direct connection exists in the target printer ?
-         if (!countElementsInTable("glpi_computers_items", 
-                                   "`itemtype` = 'Printer' 
-                                      AND `items_id` = '$new_printers_id' 
-                                         AND `computers_id`='".$connection["computers_id"]."'")) {
+         if (!countElementsInTable("glpi_computers_items",
+                                   "`itemtype` = 'Printer'
+                                       AND `items_id` = '$new_printers_id'
+                                       AND `computers_id`='".$connection["computers_id"]."'")) {
             //Direct connection doesn't exists in the target printer : move it
-            $computeritem->update(array ('id'       => $connection['id'], 
+            $computeritem->update(array ('id'       => $connection['id'],
                                          'items_id' => $new_printers_id));
          } else {
             //Direct connection already exists in the target printer : delete it
@@ -339,6 +341,7 @@ class RuleDictionnaryPrinterCollection extends RuleCachedCollection {
          }
       }
    }
+
 }
 
 ?>
\ No newline at end of file
