@@ -1,9 +1,9 @@
 <?php
 /*
- * @version $Id: ruleright.class.php 17152 2012-01-24 11:22:16Z moyo $
+ * @version $Id: ruleright.class.php 20130 2013-02-04 16:55:15Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
- Copyright (C) 2003-2012 by the INDEPNET Development Team.
+ Copyright (C) 2003-2013 by the INDEPNET Development Team.
 
  http://indepnet.net/   http://glpi-project.org
  -------------------------------------------------------------------------
@@ -104,7 +104,8 @@ class RuleRight extends Rule {
       Dropdown::showYesNo("is_recursive",0);
       echo "</td></tr>\n";
 
-      echo "</table></form>";
+      echo "</table>";
+      Html::closeForm();
    }
 
 
