@@ -1,10 +1,10 @@
 <?php
 
 /*
- * @version $Id: ticketvalidation.class.php 18430 2012-05-07 13:58:38Z yllen $
+ * @version $Id: ticketvalidation.class.php 20130 2013-02-04 16:55:15Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
- Copyright (C) 2003-2012 by the INDEPNET Development Team.
+ Copyright (C) 2003-2013 by the INDEPNET Development Team.
 
  http://indepnet.net/   http://glpi-project.org
  -------------------------------------------------------------------------
@@ -77,6 +77,23 @@ class TicketValidation  extends CommonDBChild {
    }
 
 
+   /**
+    * Is the current user have right to delete the current validation ?
+    *
+    * @since version 0.83.5
+    *
+    * @return boolean
+   */
+//    function canDeleteItem() {
+// 
+//       If (($this->fields["users_id"] == Session::getLoginUserID())
+//           || Session::haveRight('validate_ticket', 1)) {
+//          return true;
+//       }
+//       return false;
+//    }
+
+
    /**
     * Is the current user have right to update the current validation ?
     *
@@ -164,10 +181,13 @@ class TicketValidation  extends CommonDBChild {
       }
 
       $input["users_id"] = 0;
-      if (!isset($input['_auto_update'])) {
+      // Only set requester on manual action
+      if (!isset($input['_auto_import'])
+         && !isset($input['_auto_update'])
+         && is_numeric(Session::getLoginUserID(false))) {
          $input["users_id"] = Session::getLoginUserID();
       }
-
+      
       $input["submission_date"] = $_SESSION["glpi_currenttime"];
       $input["status"]          = 'waiting';
 
